export * from "./PluginNames"

export { DeviceUpdateTuple } from "./tuples/DeviceUpdateTuple"
export { SettingPropertyTuple } from "./tuples/admin/SettingPropertyTuple"
export { EnrolDeviceAction } from "./tuples/EnrolDeviceAction"
export { UpdateAppliedAction } from "./tuples/UpdateAppliedAction"
export { ClientSettingsTuple } from "./tuples/ClientSettingsTuple"
export { DeviceBackgroundStateTupleAction } from "./tuples/DeviceBackgroundStateTupleAction"
export { UpdateEnrollmentAction } from "./tuples/admin/UpdateEnrollmentAction"
export { UpdateDeviceOnlineAction } from "./tuples/UpdateDeviceOnlineAction"

export {
    AlterDeviceUpdateAction
} from "./tuples/admin/AlterDeviceUpdateAction"
export {
    CreateDeviceUpdateAction
} from "./tuples/admin/CreateDeviceUpdateAction"

export { HardwareInfo } from "./hardware-info/hardware-info.web"
export { DeviceTypeEnum } from "./hardware-info/hardware-info.abstract"

export { DeviceNavService } from "./device-nav.service"
export { DeviceServerService, ServerInfoTuple } from "./device-server.service"
export { DeviceTupleService } from "./device-tuple.service"
export { DeviceOnlineService } from "./device-online.service"